summaryrefslogtreecommitdiff
path: root/gst/videoparsers/gsth264parse.c
diff options
context:
space:
mode:
Diffstat (limited to 'gst/videoparsers/gsth264parse.c')
-rw-r--r--gst/videoparsers/gsth264parse.c9
1 files changed, 6 insertions, 3 deletions
diff --git a/gst/videoparsers/gsth264parse.c b/gst/videoparsers/gsth264parse.c
index 1a1e391d7..e103bbb8d 100644
--- a/gst/videoparsers/gsth264parse.c
+++ b/gst/videoparsers/gsth264parse.c
@@ -1902,10 +1902,13 @@ gst_h264_parse_set_caps (GstBaseParse * parse, GstCaps * caps)
}
if (format == h264parse->format && align == h264parse->align) {
- gst_base_parse_set_passthrough (parse, TRUE);
+ /* do not set CAPS and passthrough mode if SPS/PPS have not been parsed */
+ if (h264parse->have_sps && h264parse->have_pps) {
+ gst_base_parse_set_passthrough (parse, TRUE);
- /* we did parse codec-data and might supplement src caps */
- gst_h264_parse_update_src_caps (h264parse, caps);
+ /* we did parse codec-data and might supplement src caps */
+ gst_h264_parse_update_src_caps (h264parse, caps);
+ }
} else if (format == GST_H264_PARSE_FORMAT_AVC) {
/* if input != output, and input is avc, must split before anything else */
/* arrange to insert codec-data in-stream if needed.